@@ -30,6 +30,8 @@ import com.netscape.management.client.util.AbstractDialog;
 import com.netscape.management.client.util.GridBagUtil;
 import com.netscape.management.client.util.RemoteImage;
 import com.netscape.management.client.security.PromptForTrustDialog;
+import com.netscape.management.nmclf.SuiPasswordField;
+import com.netscape.management.client.preferences.Preferences;
 
 import org.mozilla.jss.ssl.SSLSocket;
 import org.mozilla.jss.ssl.SSLCertificateApprovalCallback.ValidityStatus;
@@ -45,8 +47,6 @@ import org.mozilla.jss.crypto.InternalCertificate;
 import javax.swing.JFrame;
 import javax.swing.SwingUtilities;
 
-
-import com.netscape.management.client.util.SingleBytePasswordField;
 import javax.swing.JLabel;
 import javax.swing.JComboBox;
 import javax.swing.JPanel;
@@ -75,7 +75,6 @@ public class HttpsChannel extends HttpChannel implements
     static HttpsChannel.SelectCertDialog selectCertDialog = null;
     static CertificateFactory cf;
     static ResourceSet resource;
-
     private JFrame _frame; 
 
     final static int MAX_PASSWORD_PROMPT = 10;
@@ -239,7 +238,7 @@ public class HttpsChannel extends HttpChannel implements
     class GetPasswordDialog extends AbstractDialog {
 
         JLabel enterPwdLabel = new JLabel();
-        SingleBytePasswordField pwd;
+        SuiPasswordField pwd;
         public GetPasswordDialog(JFrame parent) {
             super(parent, i18n("getPwdDialogTitle"), true, OK|CANCEL);
 
@@ -253,7 +252,7 @@ public class HttpsChannel extends HttpChannel implements
                                     GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                     0, 0, 0, 0);
 
-            pwd = new SingleBytePasswordField();
+            pwd = new SuiPasswordField();
             setFocusComponent(pwd);
             GridBagUtil.constrain(p, pwd,
                                     0, ++y, 1, 1,
@@ -404,11 +403,49 @@ public class HttpsChannel extends HttpChannel implements
         return getPasswordDialog.getPassword();
     }
 
-    public void open() throws IOException {
+    private int getSSLVersionRangeEnum (String rangeString) {
+        if (rangeString == null)
+            return -1;
+        if (rangeString.equalsIgnoreCase("ssl3"))
+            return org.mozilla.jss.ssl.SSLSocket.SSLVersionRange.ssl3;
+        else if (rangeString.equalsIgnoreCase("tls1.0"))
+            return org.mozilla.jss.ssl.SSLSocket.SSLVersionRange.tls1_0;
+        else if (rangeString.equalsIgnoreCase("tls1.1"))
+            return org.mozilla.jss.ssl.SSLSocket.SSLVersionRange.tls1_1;
+        else if (rangeString.equalsIgnoreCase("tls1.2"))
+            return org.mozilla.jss.ssl.SSLSocket.SSLVersionRange.tls1_2;
+
+        return -1;
+    }
+
+    public void open(Preferences pref) throws IOException {
         cryptoManager.setPasswordCallback(this);
         try {
             nthPrompt = 0;
+
+            // Set our defaults
+            int min = org.mozilla.jss.ssl.SSLSocket.SSLVersionRange.tls1_0;
+            int max = org.mozilla.jss.ssl.SSLSocket.SSLVersionRange.tls1_2;
+
             Debug.println("CREATE JSS SSLSocket");
+
+            if(pref != null){
+                // Check if min/max have been a preference
+                int version;
+
+                if ((version = getSSLVersionRangeEnum(pref.getString("sslVersionMin"))) != -1 ){
+                    min = version;
+                }
+                if ((version = getSSLVersionRangeEnum(pref.getString("sslVersionMax"))) != -1){
+                    max = version;
+                }
+            }
+
+            org.mozilla.jss.ssl.SSLSocket.SSLVersionRange range =
+                new org.mozilla.jss.ssl.SSLSocket.SSLVersionRange(min, max);
+
+            SSLSocket.setSSLVersionRangeDefault(org.mozilla.jss.ssl.SSLSocket.SSLProtocolVariant.STREAM, range);
+
             socket = new SSLSocket(InetAddress.getByName(getHost()),
                                    getPort(), null, 0, true, this,
                                    this);
