@@ -77,6 +77,8 @@ public class Console implements CommClient {
     public static final String PREFERENCE_LOCAL = "StorePrefsToDisk";
     public static final String PREFERENCE_X = "X";
     public static final String PREFERENCE_Y = "Y";
+    public static final String PREFERENCE_SSL_VERSION_MIN = "sslVersionMin";
+    public static final String PREFERENCE_SSL_VERSION_MAX = "sslVersionMax";
 
     public static final String PREFERENCE_DIR = System.getProperty("user.home") + File.separator +
                               _resource_theme.getString("console","prefsdir") + File.separator;
@@ -1053,7 +1055,7 @@ public class Console implements CommClient {
 
         Hashtable ht = new Hashtable();
 
-        boolean successfulAuth = invoke_task(url, user, pw, ht);
+        boolean successfulAuth = invoke_task(url, user, pw, ht, _preferences);
 
         String param;
 
@@ -1138,6 +1140,11 @@ public class Console implements CommClient {
 
     private synchronized final boolean invoke_task(URL url,
             String user, String pw, Hashtable ht) {
+        return invoke_task(url, user, pw, ht, null);
+    }
+
+    private synchronized final boolean invoke_task(URL url,
+            String user, String pw, Hashtable ht, Preferences pref) {
         HttpManager h = new HttpManager();
 
         InputStream is;
@@ -1146,7 +1153,7 @@ public class Console implements CommClient {
 
         try {
             h.get(url, this, r = new Response(user, pw),
-                    h.FORCE_BASIC_AUTH);
+                    h.FORCE_BASIC_AUTH, pref);
         } catch (Exception ioe) {
             String _url;
             try {
@@ -1603,7 +1610,11 @@ public class Console implements CommClient {
 
         if (opt.hasOption('h'))// help
         {
-            System.err.println("Syntax:  Console [-a <URL>] [-l <Language Code>] [-s <SIE DN>] [-x <options>]");
+            String prog_name = System.getProperty("program.name");
+            if ((prog_name == null) || (prog_name.length() == 0)) {
+                prog_name = "389-console";
+            }
+            System.err.println("Syntax:  " + prog_name + " [-a <URL>] [-l <Language Code>] [-s <SIE DN>] [-x <options>]");
             System.err.println("         -a admin server base URL");
             System.err.println("         -l language code (en fr gr)");
             System.err.println("         -f <file> capture stderr and stdout to <file> (like Unix tee command)");
@@ -1613,7 +1624,7 @@ public class Console implements CommClient {
             System.err.println("         -w password");
             System.err.println("         -w - (read password from standard input)");
             System.err.println("         -y password_file (read password from a file)");
-            System.err.println("\nExample: Console -a https://hostname:10021 -l en");
+            System.err.println("\nExample: " + prog_name + " -a https://hostname:10021 -l en");
             waitForKeyPress(); // allow the user to read the msg on Win NT
             System.exit(0);
         }
