@@ -50,7 +50,6 @@ import com.netscape.management.client.util.Debug;
 import com.netscape.management.client.util.LDAPUtil;
 import com.netscape.management.client.util.RemoteImage;
 import com.netscape.management.client.util.ResourceSet;
-import com.netscape.management.client.util.SingleBytePasswordField;
 import com.netscape.management.nmclf.SuiPasswordField;
 
 
@@ -130,7 +129,7 @@ INodeInfo {
         String name = null;
         String description = null;
         JCheckBox cbSSL = new JCheckBox();
-        SuiPasswordField bindPasswordField = new SingleBytePasswordField();
+        SuiPasswordField bindPasswordField = new SuiPasswordField();
         bindPasswordField.setTransparentBorder(true);
 
         // need to re-read because ldapEntry search was too narrow
@@ -188,17 +187,15 @@ INodeInfo {
             System.err.println(e);
         }
 
-        _nodeData = new NodeData[]{ _nameNodeData =
-                new NodeData("nsAdminDomainName",
-                i18n("nsAdminDomainName"), getName(), true, /*7bit*/false),
-        new NodeData("description", i18n("description"), description, true),
-        new NodeData("LDAPHost", i18n("LDAPHost"), _LDAPHost,
-                true, true), //			new NodeData("LDAPPort", i18n("LDAPPort"), _LDAPPort, true),
-                new NodeData("SSL", i18n("SSL"), cbSSL, true),
-        new NodeData("Subtree", i18n("Subtree"), _subTree,
-                true), new NodeData("BindDN", i18n("BindDN"), _bindDN,
-                true), new NodeData("BindPassword", i18n("BindPassword"),
-                bindPasswordField, true, true), };
+        _nodeData = new NodeData[]{
+            _nameNodeData = new NodeData("nsAdminDomainName", i18n("nsAdminDomainName"), getName(), true, /*7bit*/false),
+            new NodeData("description", i18n("description"), description, true),
+            new NodeData("LDAPHost", i18n("LDAPHost"), _LDAPHost, true, true),
+            // new NodeData("LDAPPort", i18n("LDAPPort"), _LDAPPort, true),
+            new NodeData("SSL", i18n("SSL"), cbSSL, true),
+            new NodeData("Subtree", i18n("Subtree"), _subTree, true),
+            new NodeData("BindDN", i18n("BindDN"), _bindDN, true),
+            new NodeData("BindPassword", i18n("BindPassword"), bindPasswordField, true, true)};
     }
 
     /**
